@@ -139,6 +139,7 @@ fn stride_offset_checked_arithmetic<D>(dim: &D, strides: &D, index: &D)
 }
 
 /// Stride offset checked general version (slices)
+#[inline]
 pub fn stride_offset_checked(dim: &[Ix], strides: &[Ix], index: &[Ix]) -> Option<isize> {
     if index.len() != dim.len() {
         return None;
@@ -207,7 +208,10 @@ pub fn do_sub<A, D: Dimension>(dims: &mut D, ptr: &mut *mut A, strides: &D,
                                axis: usize, index: Ix) {
     let dim = dims.slice()[axis];
     let stride = strides.slice()[axis];
-    assert!(index < dim);
+    ndassert!(index < dim,
+              concat!("subview: Index {} must be less than axis length {} ",
+                      "for array with shape {:?}"),
+             index, dim, *dims);
     dims.slice_mut()[axis] = 1;
     let off = stride_offset(index, stride);
     unsafe {
